==> carbon-component-mapper-3.8.4.tgz: package/esm/sub-form/sub-form.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import clsx from 'clsx';
import createUseStyles from "react-jss/dist/react-jss.esm.js";
import useFormApi from "@data-driven-forms/react-form-renderer/use-form-api";
var useStyles = createUseStyles({
  subForm: {
    '&>:not(:last-child)': {
      marginBottom: 32
    }
  }
});

var SubForm = function SubForm(_ref) {
  var fields = _ref.fields,
      component = _ref.component,
      title = _ref.title,
      description = _ref.description,
      TitleElement = _ref.TitleElement,
      DescriptionElement = _ref.DescriptionElement,
      TitleProps = _ref.TitleProps,
      DescriptionProps = _ref.DescriptionProps,
      HeaderProps = _ref.HeaderProps,
      rest = _objectWithoutProperties(_ref, ["fields", "component", "title", "description", "TitleElement", "DescriptionElement", "TitleProps", "DescriptionProps", "HeaderProps"]);

  var formOptions = useFormApi();

  var _useStyles = useStyles(),
      tab = _useStyles.tab;

  return /*#__PURE__*/React.createElement("div", _extends({}, rest, {
    className: clsx(tab, rest.className)
  }), (title || description) && /*#__PURE__*/React.createElement("div", HeaderProps, title && React.createElement(TitleElement, TitleProps, title), description && React.createElement(DescriptionElement, DescriptionProps, description)), formOptions.renderForm(fields, formOptions));
};

SubForm.propTypes = {
  fields: PropTypes.array,
  component: PropTypes.string,
  title: PropTypes.node,
  description: PropTypes.node,
  TitleElement: PropTypes.string,
  DescriptionElement: PropTypes.string,
  TitleProps: PropTypes.object,
  DescriptionProps: PropTypes.object,
  HeaderProps: PropTypes.object
};
SubForm.defaultProps = {
  TitleElement: 'h3',
  DescriptionElement: 'p'
};
export default SubForm;

==> carbon-component-mapper-3.11.4.tgz: package/esm/sub-form/sub-form.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import clsx from 'clsx';
import { createUseStyles } from "react-jss/dist/react-jss.esm.js";
import useFormApi from "@data-driven-forms/react-form-renderer/use-form-api";
var useStyles = createUseStyles({
  subForm: {
    '&>:not(:last-child)': {
      marginBottom: 32
    }
  }
});

var SubForm = function SubForm(_ref) {
  var fields = _ref.fields,
      component = _ref.component,
      title = _ref.title,
      description = _ref.description,
      TitleElement = _ref.TitleElement,
      DescriptionElement = _ref.DescriptionElement,
      TitleProps = _ref.TitleProps,
      DescriptionProps = _ref.DescriptionProps,
      HeaderProps = _ref.HeaderProps,
      rest = _objectWithoutProperties(_ref, ["fields", "component", "title", "description", "TitleElement", "DescriptionElement", "TitleProps", "DescriptionProps", "HeaderProps"]);

  var formOptions = useFormApi();

  var _useStyles = useStyles(),
      tab = _useStyles.tab;

  return /*#__PURE__*/React.createElement("div", _extends({}, rest, {
    className: clsx(tab, rest.className)
  }), (title || description) && /*#__PURE__*/React.createElement("div", HeaderProps, title && React.createElement(TitleElement, TitleProps, title), description && React.createElement(DescriptionElement, DescriptionProps, description)), formOptions.renderForm(fields, formOptions));
};

SubForm.propTypes = {
  fields: PropTypes.array,
  component: PropTypes.string,
  title: PropTypes.node,
  description: PropTypes.node,
  TitleElement: PropTypes.string,
  DescriptionElement: PropTypes.string,
  TitleProps: PropTypes.object,
  DescriptionProps: PropTypes.object,
  HeaderProps: PropTypes.object
};
SubForm.defaultProps = {
  TitleElement: 'h3',
  DescriptionElement: 'p'
};
export default SubForm;
